/**
 * Implement RS232 on windows plarform.
 * 
 * (C) Copyright (C) 2013, Datecs Ltd.
 * 
 * No part of this software may be used, stored, compiled, reproduced,
 * modified, transcribed, translated, transmitted, or transferred, in any form
 * or by any means whether electronic, mechanical, magnetic, optical,
 * or otherwise, without the express prior written permission. 
 */

#ifndef _RS232_H
#define _RS232_H

#include <windows.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Open serial port.
 *
 * @param port a pointer to NULL terminated string that contains port name.
 * @param baudRate the port baudrate.
 * @param byteSize byte size (7, 8).
 * @param parity byte parity value (ODDPARITY, EVENPARITY, NOPARITY).
 * @param stopBits byte stop bits (ONESTOPBIT, ONE5STOPBITS, TWOSTOPBITS). 
 *
 * @return On success returns handle to port; otherwise, returns INVALID_HANDLE_VALUE.
 */
HANDLE rs232_open(const char *port, int baudRate, int byteSize, int parity, int stopBits);

/**
 * Close serial port.
 *
 * @param handle port handle. 
 */
void rs232_close(HANDLE handle);

/**
 * Reads data from serial port.
 *
 * @param handle port handle. 
 * @param buf a pointed to buffer that reveived data.
 * @param len the buffer length in bytes.
 * @param nbr a pointer to the variable that receives the number of bytes read.
 *
 * @return On success returns TRUE; otherwise, returns FALSE.
 */
BOOL rs232_read(HANDLE handle, void *buf, unsigned int len, unsigned int *nbr);

/**
 * Writes data to serial port.
 *
 * @param handle port handle. 
 * @param buf a pointed to buffer that contains data.
 * @param len the data length in bytes.
 * @param nbw a pointer to the variable that receives the number of bytes written.
 *
 * @return On success returns TRUE; otherwise, returns FALSE.
 */
BOOL rs232_write(HANDLE handle, const void *buf, unsigned int len, unsigned int *nbw);

/**
 * Purges content from port buffers.
 *
 * @param handle port handle. 
 *
 * @return On success returns TRUE; otherwise, returns FALSE.
 */
BOOL rs232_purge(HANDLE handle);

#ifdef __cplusplus
}
#endif

#endif // _RS232_H